### Name: acidiq
### Title: Acifluorfen and diquat tested on Lemna minor.
### Aliases: acidiq
### Keywords: datasets

### ** Examples


## Fitting the model with freely varying ED50 values
acidiq.mfree <- drm(rgr~dose, pct, data=acidiq, fct = LL.4(),
pmodels = list(~factor(pct),~1,~1,~factor(pct) - 1), 
adjust = "bc1")

## Lack-of-fit test
anova(acidiq.mfree)
summary(acidiq.mfree)

## Plotting isobole structure
isobole(acidiq.mfree, exchange=0.1, xlim=c(0, 400), ylim=c(0,45))

## Fitting the concentration addition model
acidiq.mca <- mixture(rgr~dose, pct, data=acidiq, fct = LL.4(), 
collapse=~factor(pct), model="CA", boxcox=TRUE)

## Comparing to model with freely varying e parameter
anova(acidiq.mca, acidiq.mfree)  # rejected

## Plotting isobole based on concentration addition
isobole(acidiq.mfree, acidiq.mca, exchange=0.1, xlim=c(0, 420), ylim=c(0,45))  # poor fit

## Fitting the Hewlett model
acidiq.mhew <- mixture(rgr~dose, pct, data=acidiq, fct = LL.4(), 
collapse=~factor(pct), model="Hewlett", boxcox=TRUE)

## Comparing to model with freely varying e parameter
anova(acidiq.mfree, acidiq.mhew)  # accepted
summary(acidiq.mhew)

## Plotting isobole based on concentration addition
isobole(acidiq.mfree, acidiq.mhew, exchange=0.1, xlim=c(0, 400), ylim=c(0,45))  # good fit




